class Thermostat
  # Sets the current temperature
  # @return [Double] the current temperature
  attr_accessor :temp_curr
  # @return [Double] the wanted temperature
  attr_accessor :temp_wanted
  # @return [Double] the lower and upper margin around the wanted temperature
  attr_accessor :range
  # @return the status of the airco
  attr_reader :airco
  # @return the status of the heater
  attr_reader :heater

  # The [initialize] method creates a Thermostat
  # @param settings [String] a json object containing the following attributes
  #   * range [Double] the lower and upper margin around the wanted temperature
  #   * temp_wanted [Double] the wanted temperature
  #   * temp_curr [Double] the current temperature
  def initialize(args)
    @range = args.fetch(:range, 1.0)
    @temp_wanted = args.fetch(:temp_wanted, 20.0)
    @temp_curr = args.fetch(:temp_curr, 20.0)
    @airco = false
    @heater = false
  end

  # The [check_temp] method updates the airco and heater based on temp_curr
  def check_temp
    if @temp_curr > (@temp_wanted + @range / 2)
      @airco = true
      @heater = false
    elsif @temp_curr < (@temp_wanted - @range / 2)
      @airco = false
      @heater = true
    else
      @airco = false
      @heater = false
    end
  end
end
